pub struct RenderError {
pub ty: ErrorType,
pub description: String,
pub source: Option<WgpuWrapper<Box<dyn Error + Sync + Send>>>,
}Expand description
An error encountered during rendering. These are errors reported by wgpu validation layers, and typically indicate problems in the way it is being used.
Fields
ty: ErrorTypedescription: Stringsource: Option<WgpuWrapper<Box<dyn Error + Sync + Send>>>Trait Implementations